[Libreoffice-commits] core.git: include/osl sal/osl sal/qa

Stephan Bergmann sbergman at redhat.com
Tue May 13 01:43:51 PDT 2014


 include/osl/detail/file.h    |   18 ------------------
 sal/osl/unx/file.cxx         |    5 +++--
 sal/osl/unx/file_impl.hxx    |    5 +++++
 sal/osl/unx/file_misc.cxx    |    4 ++--
 sal/osl/unx/file_stat.cxx    |    1 -
 sal/qa/osl/file/osl_File.cxx |    1 -
 6 files changed, 10 insertions(+), 24 deletions(-)

New commits:
commit 9a8411d3b13a4e3675f99f36d5b6e81c5eace9b6
Author: Stephan Bergmann <sbergman at redhat.com>
Date:   Tue May 13 10:43:15 2014 +0200

    osl_openFilePath is internal sal/osl/unx functionality
    
    Change-Id: I14e4d08f209e3d6a444d6c09f9ffb9c178d8731d

diff --git a/include/osl/detail/file.h b/include/osl/detail/file.h
index ddcc47e..96d8807 100644
--- a/include/osl/detail/file.h
+++ b/include/osl/detail/file.h
@@ -12,36 +12,18 @@
 
 #include <sal/config.h>
 
-#include <sys/stat.h>
-
-#include <sal/saldllapi.h>
-#include <sal/types.h>
-
 /** @cond INTERNAL */
 
 /* Some additions to the osl file functions for LibreOffice internal
    use. Needed for details in the Android support.
  */
 
-#if defined __cplusplus
-extern "C" {
-#endif
-
 /* More flags needed for semantics that match the open() call that
    used to be in SvFileStream::Open().
 */
 #define osl_File_OpenFlag_Trunc     0x00000010L
 #define osl_File_OpenFlag_NoExcl    0x00000020L
 
-SAL_DLLPUBLIC oslFileError SAL_CALL osl_openFilePath(
-    const char *cpFilePath,
-    oslFileHandle* pHandle,
-    sal_uInt32 uFlags );
-
-#if defined __cplusplus
-}
-#endif
-
 /** @endcond */
 
 #endif /* INCLUDED_OSL_DETAIL_FILE_H */
diff --git a/sal/osl/unx/file.cxx b/sal/osl/unx/file.cxx
index 330f194..72fda5a 100644
--- a/sal/osl/unx/file.cxx
+++ b/sal/osl/unx/file.cxx
@@ -33,6 +33,7 @@
 #include "system.h"
 #include "createfilehandlefromfd.hxx"
 #include "file_error_transl.h"
+#include "file_impl.hxx"
 #include "file_url.h"
 #include "uunxapi.h"
 
@@ -820,7 +821,7 @@ openMemoryAsFile( void *address, size_t size, oslFileHandle *pHandle, const char
 #endif
 
 oslFileError
-SAL_CALL osl_openFilePath( const char *cpFilePath, oslFileHandle* pHandle, sal_uInt32 uFlags )
+openFilePath( const char *cpFilePath, oslFileHandle* pHandle, sal_uInt32 uFlags )
 {
     oslFileError eRet;
 
@@ -1015,7 +1016,7 @@ SAL_CALL osl_openFile( rtl_uString* ustrFileURL, oslFileHandle* pHandle, sal_uIn
         return oslTranslateFileError (OSL_FET_ERROR, errno);
 #endif /* MACOSX */
 
-    return osl_openFilePath (buffer, pHandle, uFlags);
+    return openFilePath (buffer, pHandle, uFlags);
 }
 
 oslFileError
diff --git a/sal/osl/unx/file_impl.hxx b/sal/osl/unx/file_impl.hxx
index 7d90b3d..db8ce4e 100644
--- a/sal/osl/unx/file_impl.hxx
+++ b/sal/osl/unx/file_impl.hxx
@@ -43,6 +43,11 @@ struct DirectoryItem_Impl
     oslFileType getFileType() const;
 };
 
+oslFileError openFilePath(
+    const char *cpFilePath,
+    oslFileHandle* pHandle,
+    sal_uInt32 uFlags );
+
 #endif /* INCLUDED_FILE_IMPL_HXX */
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/sal/osl/unx/file_stat.cxx b/sal/osl/unx/file_stat.cxx
index 6c5f6a6..ce6c5d9 100644
--- a/sal/osl/unx/file_stat.cxx
+++ b/sal/osl/unx/file_stat.cxx
@@ -18,7 +18,6 @@
  */
 
 #include "osl/file.h"
-#include "osl/detail/file.h"
 
 #include "system.h"
 #include <sys/types.h>
diff --git a/sal/qa/osl/file/osl_File.cxx b/sal/qa/osl/file/osl_File.cxx
index 0a387e8..ba0a3a0 100644
--- a/sal/qa/osl/file/osl_File.cxx
+++ b/sal/qa/osl/file/osl_File.cxx
@@ -26,7 +26,6 @@
 #include "osl/thread.h"
 
 #include <osl/file.hxx>
-#include <osl/detail/file.h>
 #include <osl_File_Const.h>
 
 #include <cppunit/TestFixture.h>


More information about the Libreoffice-commits mailing list
diff --git a/sal/osl/unx/file_misc.cxx b/sal/osl/unx/file_misc.cxx
index f238f28..7662d9f 100644
--- a/sal/osl/unx/file_misc.cxx
+++ b/sal/osl/unx/file_misc.cxx
@@ -915,11 +915,11 @@ static int oslDoCopyFile(const sal_Char* pszSourceFileName, const sal_Char* pszD
     int DestFileFD=0;
     int nRet=0;
 
-    if (osl_openFilePath(pszSourceFileName,
+    if (openFilePath(pszSourceFileName,
                          &SourceFileFH,
                          osl_File_OpenFlag_Read|osl_File_OpenFlag_NoLock|osl_File_OpenFlag_NoExcl) != osl_File_E_None)
     {
         // Let's hope errno is still set relevantly after osl_openFilePath...
         nRet=errno;
         return nRet;
     }
@@ -915,11 +915,11 @@ static int oslDoCopyFile(const sal_Char* pszSourceFileName, const sal_Char* pszD
                          osl_File_OpenFlag_Read|osl_File_OpenFlag_NoLock|osl_File_OpenFlag_NoExcl) != osl_File_E_None)
     {
-        // Let's hope errno is still set relevantly after osl_openFilePath...
+        // Let's hope errno is still set relevantly after openFilePath...
         nRet=errno;
         return nRet;